Module: Google::Apis::StoragebatchoperationsV1
- Defined in:
- lib/google/apis/storagebatchoperations_v1.rb,
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/service.rb,
lib/google/apis/storagebatchoperations_v1/gem_version.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Storage Batch Operations API
Defined Under Namespace
Classes: AccessControlsUpdates, Bucket, BucketList, BucketOperation, CancelJobRequest, CancelJobResponse, CancelOperationRequest, Counters, CustomContextUpdates, DeleteObject, Empty, ErrorLogEntry, ErrorSummary, Expr, Job, ListBucketOperationsResponse, ListJobsResponse, ListLocationsResponse, ListOperationsResponse, Location, LoggingConfig, Manifest, ObjectAccessControl, ObjectCustomContextPayload, ObjectRetention, Operation, OperationMetadata, PrefixList, ProjectSource, PutMetadata, PutObjectHold, RewriteObject, SetObjectAcls, Status, StorageBatchOperationsService, TargetLocations, UpdateObjectCustomContext
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-storagebatchoperations_v1 gem
"0.17.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260601"- VERSION =
Version of the Storage Batch Operations API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'