Class: Google::Apis::StoragebatchoperationsV1::BucketList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes list of buckets and their objects to be transformed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BucketList

Returns a new instance of BucketList.



93
94
95
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 93

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketsArray<Google::Apis::StoragebatchoperationsV1::Bucket>

Required. List of buckets and their objects to be transformed. You can specify only one bucket per job. If multiple buckets are specified, an error occurs. Corresponds to the JSON property buckets



91
92
93
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 91

def buckets
  @buckets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



98
99
100
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 98

def update!(**args)
  @buckets = args[:buckets] if args.key?(:buckets)
end