Class: Google::Apis::StoragebatchoperationsV1::BucketOperation
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::BucketOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
BucketOperation represents a bucket-level breakdown of a Job.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The bucket name of the objects to be transformed in the BucketOperation.
-
#complete_time ⇒ String
Output only.
-
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
-
#create_time ⇒ String
Output only.
-
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
-
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only.
-
#manifest ⇒ Google::Apis::StoragebatchoperationsV1::Manifest
Describes list of objects to be transformed.
-
#name ⇒ String
Identifier.
-
#prefix_list ⇒ Google::Apis::StoragebatchoperationsV1::PrefixList
Describes prefixes of objects to be transformed.
-
#project_source ⇒ Google::Apis::StoragebatchoperationsV1::ProjectSource
Describes the project source where the objects satisfying the filters will be transformed.
-
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
-
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
-
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
-
#set_object_acls ⇒ Google::Apis::StoragebatchoperationsV1::SetObjectAcls
Describes options for setting object ACLs.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BucketOperation
constructor
A new instance of BucketOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BucketOperation
Returns a new instance of BucketOperation.
195 196 197 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
The bucket name of the objects to be transformed in the BucketOperation.
Corresponds to the JSON property bucketName
110 111 112 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 110 def bucket_name @bucket_name end |
#complete_time ⇒ String
Output only. The time that the BucketOperation was completed.
Corresponds to the JSON property completeTime
115 116 117 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 115 def complete_time @complete_time end |
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
Corresponds to the JSON property counters
120 121 122 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 120 def counters @counters end |
#create_time ⇒ String
Output only. The time that the BucketOperation was created.
Corresponds to the JSON property createTime
125 126 127 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 125 def create_time @create_time end |
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
Corresponds to the JSON property deleteObject
130 131 132 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 130 def delete_object @delete_object end |
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only. Summarizes errors encountered with sample error log entries.
Corresponds to the JSON property errorSummaries
135 136 137 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 135 def error_summaries @error_summaries end |
#manifest ⇒ Google::Apis::StoragebatchoperationsV1::Manifest
Describes list of objects to be transformed.
Corresponds to the JSON property manifest
140 141 142 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 140 def manifest @manifest end |
#name ⇒ String
Identifier. The resource name of the BucketOperation. This is defined by the
service. Format: projects/project_id/locations/global/jobs/job_id/
bucketOperations/bucket_operation`.
Corresponds to the JSON propertyname`
147 148 149 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 147 def name @name end |
#prefix_list ⇒ Google::Apis::StoragebatchoperationsV1::PrefixList
Describes prefixes of objects to be transformed.
Corresponds to the JSON property prefixList
152 153 154 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 152 def prefix_list @prefix_list end |
#project_source ⇒ Google::Apis::StoragebatchoperationsV1::ProjectSource
Describes the project source where the objects satisfying the filters will be
transformed.
Corresponds to the JSON property projectSource
158 159 160 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 158 def project_source @project_source end |
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
Corresponds to the JSON property putMetadata
163 164 165 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 163 def @put_metadata end |
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
Corresponds to the JSON property putObjectHold
168 169 170 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 168 def put_object_hold @put_object_hold end |
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
Corresponds to the JSON property rewriteObject
173 174 175 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 173 def rewrite_object @rewrite_object end |
#set_object_acls ⇒ Google::Apis::StoragebatchoperationsV1::SetObjectAcls
Describes options for setting object ACLs.
Corresponds to the JSON property setObjectAcls
178 179 180 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 178 def set_object_acls @set_object_acls end |
#start_time ⇒ String
Output only. The time that the BucketOperation was started.
Corresponds to the JSON property startTime
183 184 185 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 183 def start_time @start_time end |
#state ⇒ String
Output only. State of the BucketOperation.
Corresponds to the JSON property state
188 189 190 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 188 def state @state end |
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Corresponds to the JSON property updateObjectCustomContext
193 194 195 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 193 def update_object_custom_context @update_object_custom_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 200 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @complete_time = args[:complete_time] if args.key?(:complete_time) @counters = args[:counters] if args.key?(:counters) @create_time = args[:create_time] if args.key?(:create_time) @delete_object = args[:delete_object] if args.key?(:delete_object) @error_summaries = args[:error_summaries] if args.key?(:error_summaries) @manifest = args[:manifest] if args.key?(:manifest) @name = args[:name] if args.key?(:name) @prefix_list = args[:prefix_list] if args.key?(:prefix_list) @project_source = args[:project_source] if args.key?(:project_source) @put_metadata = args[:put_metadata] if args.key?(:put_metadata) @put_object_hold = args[:put_object_hold] if args.key?(:put_object_hold) @rewrite_object = args[:rewrite_object] if args.key?(:rewrite_object) @set_object_acls = args[:set_object_acls] if args.key?(:set_object_acls) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_object_custom_context = args[:update_object_custom_context] if args.key?(:update_object_custom_context) end |