Class: Google::Apis::StoragebatchoperationsV1::CustomContextUpdates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes a collection of updates to apply to custom contexts identified by key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomContextUpdates

Returns a new instance of CustomContextUpdates.



309
310
311
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keys_to_clearArray<String>

Optional. Custom contexts to clear by key. A key cannot be present in both updates and keys_to_clear. Corresponds to the JSON property keysToClear

Returns:

  • (Array<String>)


302
303
304
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 302

def keys_to_clear
  @keys_to_clear
end

#updatesHash<String,Google::Apis::StoragebatchoperationsV1::ObjectCustomContextPayload>

Optional. Insert or update the existing custom contexts. Corresponds to the JSON property updates



307
308
309
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 307

def updates
  @updates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



314
315
316
317
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 314

def update!(**args)
  @keys_to_clear = args[:keys_to_clear] if args.key?(:keys_to_clear)
  @updates = args[:updates] if args.key?(:updates)
end