Class: Google::Apis::StoragebatchoperationsV1::Manifest
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::Manifest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Describes list of objects to be transformed.
Instance Attribute Summary collapse
-
#manifest_location ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Manifest
constructor
A new instance of Manifest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Manifest
Returns a new instance of Manifest.
876 877 878 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#manifest_location ⇒ String
Required. Specify the manifest file location. The format of manifest location
can be an absolute path to the object in the format of gs://bucket_name/path/
object_name. For example, gs://bucket_name/path/object_name.csv.
Alternatively, you can specify an absolute path with a single wildcard
character in the file name, for example gs://bucket_name/path/file_name*.csv.
If the manifest location is specified with a wildcard, objects in all
manifest files matching the pattern will be acted upon. The manifest is a CSV
file, uploaded to Cloud Storage, that contains one object or a list of objects
that you want to process. Each row in the manifest must include the bucket
and name of the object. You can optionally specify the generation of the
object. If you don't specify the generation, the current version of the
object is used. You can optionally include a header row with the following
format: bucket,name,generation. For example, bucket,name,generation bucket_1,
object_1,generation_1 bucket_1,object_2,generation_2 bucket_1,object_3,
generation_3 Note: The manifest file must specify only objects within the
bucket provided to the job. Rows referencing objects in other buckets are
ignored.
Corresponds to the JSON property manifestLocation
874 875 876 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 874 def manifest_location @manifest_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
881 882 883 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 881 def update!(**args) @manifest_location = args[:manifest_location] if args.key?(:manifest_location) end |