Class: Google::Apis::StoragebatchoperationsV1::PrefixList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes prefixes of objects to be transformed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrefixList

Returns a new instance of PrefixList.



1094
1095
1096
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#included_object_prefixesArray<String>

Optional. Specify one or more object prefixes. For example: * To match one object, use a single prefix, prefix1. * To match multiple objects, use comma- separated prefixes, prefix1, prefix2. * To match all objects, use an empty prefix, '' Corresponds to the JSON property includedObjectPrefixes

Returns:

  • (Array<String>)


1092
1093
1094
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1092

def included_object_prefixes
  @included_object_prefixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1099
1100
1101
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1099

def update!(**args)
  @included_object_prefixes = args[:included_object_prefixes] if args.key?(:included_object_prefixes)
end