Class: Google::Apis::StoragebatchoperationsV1::PutMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes options for object metadata update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PutMetadata

Returns a new instance of PutMetadata.



1266
1267
1268
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_controlString

Optional. Updates the objects Cache-Control fixed metadata. Unset values in the request are ignored. To clear the metadata, set an empty value. Additionally, the value for Custom-Time can't decrease. For details, see Cache-Control. Corresponds to the JSON property cacheControl

Returns:

  • (String)


1208
1209
1210
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1208

def cache_control
  @cache_control
end

#content_dispositionString

Optional. Updates objects Content-Disposition fixed metadata. Unset values in the request are ignored. To clear the metadata, set an empty value. For details, see Content-Disposition. Corresponds to the JSON property contentDisposition

Returns:

  • (String)


1216
1217
1218
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1216

def content_disposition
  @content_disposition
end

#content_encodingString

Optional. Updates the objects Content-Encoding fixed metadata. Unset values in the request are ignored. To clear the metadata, set an empty value. For details, see Content-Encoding. Corresponds to the JSON property contentEncoding

Returns:

  • (String)


1224
1225
1226
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1224

def content_encoding
  @content_encoding
end

#content_languageString

Optional. Updates the objects Content-Language fixed metadata. Metadata values must use ISO 639-1 language codes. The maximum length for metadata values is 100 characters. Unset values in the request are ignored. To clear the metadata, set an empty value. For details, see Content-Language. Corresponds to the JSON property contentLanguage

Returns:

  • (String)


1233
1234
1235
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1233

def content_language
  @content_language
end

#content_typeString

Optional. Updates objects Content-Type fixed metadata. Unset values in the request are ignored. To clear the metadata, set an empty value. For details, see Content-Type . Corresponds to the JSON property contentType

Returns:

  • (String)


1241
1242
1243
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1241

def content_type
  @content_type
end

#custom_metadataHash<String,String>

Optional. Updates the object's custom metadata. This operation adds or sets individual custom metadata key-value pairs. Keys specified with empty values have their values cleared. Existing custom metadata keys not included in the request remain unchanged. For details, see Custom metadata. Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,String>)


1250
1251
1252
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1250

def 
  @custom_metadata
end

#custom_timeString

Optional. Updates the objects Custom-Time fixed metadata. Unset values in the request are ignored. To clear the metadata, set an empty value. The time must be specified in RFC 3339 format, for example YYYY-MM-DD'T'HH:MM:SS'Z' or YYYY-MM-DD'T'HH:MM:SS.SS'Z'. For details, see Custom-Time. Corresponds to the JSON property customTime

Returns:

  • (String)


1259
1260
1261
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1259

def custom_time
  @custom_time
end

#object_retentionGoogle::Apis::StoragebatchoperationsV1::ObjectRetention

Describes options for object retention update. Corresponds to the JSON property objectRetention



1264
1265
1266
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1264

def object_retention
  @object_retention
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1271

def update!(**args)
  @cache_control = args[:cache_control] if args.key?(:cache_control)
  @content_disposition = args[:content_disposition] if args.key?(:content_disposition)
  @content_encoding = args[:content_encoding] if args.key?(:content_encoding)
  @content_language = args[:content_language] if args.key?(:content_language)
  @content_type = args[:content_type] if args.key?(:content_type)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @custom_time = args[:custom_time] if args.key?(:custom_time)
  @object_retention = args[:object_retention] if args.key?(:object_retention)
end