Class: Google::Apis::StoragebatchoperationsV1::TargetLocations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes the Cloud Storage locations to include in a ProjectSource job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetLocations

Returns a new instance of TargetLocations.



1427
1428
1429
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationsArray<String>

Required. REQUIRED. A list of Cloud Storage locations (e.g., us-central1) to include in the job. If snapshot_time is omitted, the job automatically defaults to the most recent snapshot timestamp that is successfully populated in BOTH the object_attributes_view and bucket_attributes_view across ALL specified locations. For details on Storage Insights dataset snapshots and views, see: https://docs.cloud.google.com/storage/docs/insights/dataset-tables- and-schemas#schema Corresponds to the JSON property locations

Returns:

  • (Array<String>)


1416
1417
1418
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1416

def locations
  @locations
end

#snapshot_timeString

Optional. OPTIONAL. The exact Storage Insights snapshot timestamp to use for the job compatible with the RFC 3339 format (e.g., 2024-01-02T03:04:05Z). If specified, this exact snapshot must exist in BOTH the object_attributes_view and bucket_attributes_view for every location listed in locations. If the snapshot is missing from either view in any of the locations, the job fails. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


1425
1426
1427
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1425

def snapshot_time
  @snapshot_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1432
1433
1434
1435
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1432

def update!(**args)
  @locations = args[:locations] if args.key?(:locations)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
end