Class: Google::Apis::StoragebatchoperationsV1::BucketList
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::BucketList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Describes list of buckets and their objects to be transformed.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ BucketList
constructor
A new instance of BucketList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BucketList
Returns a new instance of BucketList.
67 68 69 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 67 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buckets ⇒ Array<Google::Apis::StoragebatchoperationsV1::Bucket>
Required. List of buckets and their objects to be transformed. Currently, only
one bucket configuration is supported. If multiple buckets are specified, an
error will be returned.
Corresponds to the JSON property buckets
65 66 67 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 65 def buckets @buckets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72 73 74 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 72 def update!(**args) @buckets = args[:buckets] if args.key?(:buckets) end |