Class: Google::Apis::StoragebatchoperationsV1::BucketOperation
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::BucketOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
BucketOperation represents a bucket-level breakdown of a Job.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The bucket name of the objects to be transformed in the BucketOperation.
-
#complete_time ⇒ String
Output only.
-
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
-
#create_time ⇒ String
Output only.
-
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
-
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only.
-
#manifest ⇒ Google::Apis::StoragebatchoperationsV1::Manifest
Describes list of objects to be transformed.
-
#name ⇒ String
Identifier.
-
#prefix_list ⇒ Google::Apis::StoragebatchoperationsV1::PrefixList
Describes prefixes of objects to be transformed.
-
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
-
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
-
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BucketOperation
constructor
A new instance of BucketOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BucketOperation
Returns a new instance of BucketOperation.
158 159 160 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 158 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
The bucket name of the objects to be transformed in the BucketOperation.
Corresponds to the JSON property bucketName
84 85 86 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 84 def bucket_name @bucket_name end |
#complete_time ⇒ String
Output only. The time that the BucketOperation was completed.
Corresponds to the JSON property completeTime
89 90 91 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 89 def complete_time @complete_time end |
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
Corresponds to the JSON property counters
94 95 96 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 94 def counters @counters end |
#create_time ⇒ String
Output only. The time that the BucketOperation was created.
Corresponds to the JSON property createTime
99 100 101 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 99 def create_time @create_time end |
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
Corresponds to the JSON property deleteObject
104 105 106 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 104 def delete_object @delete_object end |
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only. Summarizes errors encountered with sample error log entries.
Corresponds to the JSON property errorSummaries
109 110 111 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 109 def error_summaries @error_summaries end |
#manifest ⇒ Google::Apis::StoragebatchoperationsV1::Manifest
Describes list of objects to be transformed.
Corresponds to the JSON property manifest
114 115 116 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 114 def manifest @manifest end |
#name ⇒ String
Identifier. The resource name of the BucketOperation. This is defined by the
service. Format: projects/project/locations/global/jobs/job_id/
bucketOperations/bucket_operation.
Corresponds to the JSON property name
121 122 123 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 121 def name @name end |
#prefix_list ⇒ Google::Apis::StoragebatchoperationsV1::PrefixList
Describes prefixes of objects to be transformed.
Corresponds to the JSON property prefixList
126 127 128 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 126 def prefix_list @prefix_list end |
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
Corresponds to the JSON property putMetadata
131 132 133 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 131 def @put_metadata end |
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
Corresponds to the JSON property putObjectHold
136 137 138 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 136 def put_object_hold @put_object_hold end |
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
Corresponds to the JSON property rewriteObject
141 142 143 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 141 def rewrite_object @rewrite_object end |
#start_time ⇒ String
Output only. The time that the BucketOperation was started.
Corresponds to the JSON property startTime
146 147 148 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 146 def start_time @start_time end |
#state ⇒ String
Output only. State of the BucketOperation.
Corresponds to the JSON property state
151 152 153 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 151 def state @state end |
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Corresponds to the JSON property updateObjectCustomContext
156 157 158 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 156 def update_object_custom_context @update_object_custom_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 163 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @complete_time = args[:complete_time] if args.key?(:complete_time) @counters = args[:counters] if args.key?(:counters) @create_time = args[:create_time] if args.key?(:create_time) @delete_object = args[:delete_object] if args.key?(:delete_object) @error_summaries = args[:error_summaries] if args.key?(:error_summaries) @manifest = args[:manifest] if args.key?(:manifest) @name = args[:name] if args.key?(:name) @prefix_list = args[:prefix_list] if args.key?(:prefix_list) @put_metadata = args[:put_metadata] if args.key?(:put_metadata) @put_object_hold = args[:put_object_hold] if args.key?(:put_object_hold) @rewrite_object = args[:rewrite_object] if args.key?(:rewrite_object) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_object_custom_context = args[:update_object_custom_context] if args.key?(:update_object_custom_context) end |