Class: Google::Apis::StoragebatchoperationsV1::Counters
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::Counters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Describes details about the progress of the job.
Instance Attribute Summary collapse
-
#failed_object_count ⇒ Fixnum
Output only.
-
#object_custom_contexts_created ⇒ Fixnum
Output only.
-
#object_custom_contexts_deleted ⇒ Fixnum
Output only.
-
#object_custom_contexts_updated ⇒ Fixnum
Output only.
-
#succeeded_object_count ⇒ Fixnum
Output only.
-
#total_bytes_found ⇒ Fixnum
Output only.
-
#total_object_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Counters
constructor
A new instance of Counters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Counters
Returns a new instance of Counters.
277 278 279 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_object_count ⇒ Fixnum
Output only. The number of objects that failed due to user errors or service
errors.
Corresponds to the JSON property failedObjectCount
239 240 241 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 239 def failed_object_count @failed_object_count end |
#object_custom_contexts_created ⇒ Fixnum
Output only. Number of object custom contexts created. This field is only
populated for jobs with the UpdateObjectCustomContext transformation.
Corresponds to the JSON property objectCustomContextsCreated
245 246 247 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 245 def object_custom_contexts_created @object_custom_contexts_created end |
#object_custom_contexts_deleted ⇒ Fixnum
Output only. Number of object custom contexts deleted. This field is only
populated for jobs with the UpdateObjectCustomContext transformation.
Corresponds to the JSON property objectCustomContextsDeleted
251 252 253 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 251 def object_custom_contexts_deleted @object_custom_contexts_deleted end |
#object_custom_contexts_updated ⇒ Fixnum
Output only. Number of object custom contexts updated. This counter tracks
custom contexts where the key already existed, but the payload was modified.
This field is only populated for jobs with the UpdateObjectCustomContext
transformation.
Corresponds to the JSON property objectCustomContextsUpdated
259 260 261 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 259 def object_custom_contexts_updated @object_custom_contexts_updated end |
#succeeded_object_count ⇒ Fixnum
Output only. Number of objects completed.
Corresponds to the JSON property succeededObjectCount
264 265 266 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 264 def succeeded_object_count @succeeded_object_count end |
#total_bytes_found ⇒ Fixnum
Output only. Number of bytes found from source. This field is only populated
for jobs with a prefix list object configuration.
Corresponds to the JSON property totalBytesFound
270 271 272 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 270 def total_bytes_found @total_bytes_found end |
#total_object_count ⇒ Fixnum
Output only. Number of objects listed.
Corresponds to the JSON property totalObjectCount
275 276 277 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 275 def total_object_count @total_object_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
282 283 284 285 286 287 288 289 290 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 282 def update!(**args) @failed_object_count = args[:failed_object_count] if args.key?(:failed_object_count) @object_custom_contexts_created = args[:object_custom_contexts_created] if args.key?(:object_custom_contexts_created) @object_custom_contexts_deleted = args[:object_custom_contexts_deleted] if args.key?(:object_custom_contexts_deleted) @object_custom_contexts_updated = args[:object_custom_contexts_updated] if args.key?(:object_custom_contexts_updated) @succeeded_object_count = args[:succeeded_object_count] if args.key?(:succeeded_object_count) @total_bytes_found = args[:total_bytes_found] if args.key?(:total_bytes_found) @total_object_count = args[:total_object_count] if args.key?(:total_object_count) end |