Class: Google::Apis::StoragebatchoperationsV1::DeleteObject
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::DeleteObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Describes options to delete an object.
Instance Attribute Summary collapse
-
#permanent_object_deletion_enabled ⇒ Boolean
(also: #permanent_object_deletion_enabled?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteObject
constructor
A new instance of DeleteObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteObject
Returns a new instance of DeleteObject.
338 339 340 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#permanent_object_deletion_enabled ⇒ Boolean Also known as: permanent_object_deletion_enabled?
Required. Controls deletion behavior when versioning is enabled for the object'
s bucket. If true both live and noncurrent objects will be permanently deleted.
Otherwise live objects in versioned buckets will become noncurrent and
objects that were already noncurrent will be skipped. This setting doesn't
have any impact on the Soft Delete feature. All objects deleted by this
service can be be restored for the duration of the Soft Delete retention
duration if enabled. If enabled and the manifest doesn't specify an object's
generation, a GetObjectMetadata call (a Class B operation) will be made to
determine the live object generation.
Corresponds to the JSON property permanentObjectDeletionEnabled
335 336 337 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 335 def permanent_object_deletion_enabled @permanent_object_deletion_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
343 344 345 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 343 def update!(**args) @permanent_object_deletion_enabled = args[:permanent_object_deletion_enabled] if args.key?(:permanent_object_deletion_enabled) end |