Class: Google::Apis::StoragebatchoperationsV1::Job
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
The storage batch operations job description.
Instance Attribute Summary collapse
-
#bucket_list ⇒ Google::Apis::StoragebatchoperationsV1::BucketList
Describes list of buckets and their objects to be transformed.
-
#complete_time ⇒ String
Output only.
-
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
-
#create_time ⇒ String
Output only.
-
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
-
#description ⇒ String
Optional.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only.
-
#is_multi_bucket_job ⇒ Boolean
(also: #is_multi_bucket_job?)
Output only.
-
#logging_config ⇒ Google::Apis::StoragebatchoperationsV1::LoggingConfig
Specifies the Cloud Logging behavior.
-
#name ⇒ String
Identifier.
-
#project_source ⇒ Google::Apis::StoragebatchoperationsV1::ProjectSource
Describes the project source where the objects satisfying the filters will be transformed.
-
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
-
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
-
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
-
#schedule_time ⇒ String
Output only.
-
#set_object_acls ⇒ Google::Apis::StoragebatchoperationsV1::SetObjectAcls
Describes options for setting object ACLs.
-
#state ⇒ String
Output only.
-
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
630 631 632 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_list ⇒ Google::Apis::StoragebatchoperationsV1::BucketList
Describes list of buckets and their objects to be transformed.
Corresponds to the JSON property bucketList
529 530 531 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 529 def bucket_list @bucket_list end |
#complete_time ⇒ String
Output only. The time that the job was completed.
Corresponds to the JSON property completeTime
534 535 536 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 534 def complete_time @complete_time end |
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
Corresponds to the JSON property counters
539 540 541 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 539 def counters @counters end |
#create_time ⇒ String
Output only. The time that the job was created.
Corresponds to the JSON property createTime
544 545 546 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 544 def create_time @create_time end |
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
Corresponds to the JSON property deleteObject
549 550 551 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 549 def delete_object @delete_object end |
#description ⇒ String
Optional. A user-provided description for the job. Maximum length: 1024 bytes
when unicode-encoded.
Corresponds to the JSON property description
555 556 557 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 555 def description @description end |
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. If true, the job runs in dry run mode, returning the total object
count and, if the object configuration is a prefix list, the bytes found from
source. No transformations are performed.
Corresponds to the JSON property dryRun
562 563 564 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 562 def dry_run @dry_run end |
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only. Summarizes errors encountered with sample error log entries.
Corresponds to the JSON property errorSummaries
568 569 570 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 568 def error_summaries @error_summaries end |
#is_multi_bucket_job ⇒ Boolean Also known as: is_multi_bucket_job?
Output only. If true, this job operates on multiple buckets. Multi-bucket jobs
are subject to different quota limits than single-bucket jobs.
Corresponds to the JSON property isMultiBucketJob
574 575 576 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 574 def is_multi_bucket_job @is_multi_bucket_job end |
#logging_config ⇒ Google::Apis::StoragebatchoperationsV1::LoggingConfig
Specifies the Cloud Logging behavior.
Corresponds to the JSON property loggingConfig
580 581 582 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 580 def logging_config @logging_config end |
#name ⇒ String
Identifier. The resource name of the job. Format: projects/project_id/
locations/global/jobs/job_id`. For example:projects/123456/locations/
global/jobs/job01.job_idis unique in a given project.
Corresponds to the JSON propertyname`
587 588 589 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 587 def name @name end |
#project_source ⇒ Google::Apis::StoragebatchoperationsV1::ProjectSource
Describes the project source where the objects satisfying the filters will be
transformed.
Corresponds to the JSON property projectSource
593 594 595 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 593 def project_source @project_source end |
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
Corresponds to the JSON property putMetadata
598 599 600 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 598 def @put_metadata end |
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
Corresponds to the JSON property putObjectHold
603 604 605 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 603 def put_object_hold @put_object_hold end |
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
Corresponds to the JSON property rewriteObject
608 609 610 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 608 def rewrite_object @rewrite_object end |
#schedule_time ⇒ String
Output only. The time that the job was scheduled.
Corresponds to the JSON property scheduleTime
613 614 615 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 613 def schedule_time @schedule_time end |
#set_object_acls ⇒ Google::Apis::StoragebatchoperationsV1::SetObjectAcls
Describes options for setting object ACLs.
Corresponds to the JSON property setObjectAcls
618 619 620 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 618 def set_object_acls @set_object_acls end |
#state ⇒ String
Output only. State of the job.
Corresponds to the JSON property state
623 624 625 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 623 def state @state end |
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Corresponds to the JSON property updateObjectCustomContext
628 629 630 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 628 def update_object_custom_context @update_object_custom_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 635 def update!(**args) @bucket_list = args[:bucket_list] if args.key?(:bucket_list) @complete_time = args[:complete_time] if args.key?(:complete_time) @counters = args[:counters] if args.key?(:counters) @create_time = args[:create_time] if args.key?(:create_time) @delete_object = args[:delete_object] if args.key?(:delete_object) @description = args[:description] if args.key?(:description) @dry_run = args[:dry_run] if args.key?(:dry_run) @error_summaries = args[:error_summaries] if args.key?(:error_summaries) @is_multi_bucket_job = args[:is_multi_bucket_job] if args.key?(:is_multi_bucket_job) @logging_config = args[:logging_config] if args.key?(:logging_config) @name = args[:name] if args.key?(:name) @project_source = args[:project_source] if args.key?(:project_source) @put_metadata = args[:put_metadata] if args.key?(:put_metadata) @put_object_hold = args[:put_object_hold] if args.key?(:put_object_hold) @rewrite_object = args[:rewrite_object] if args.key?(:rewrite_object) @schedule_time = args[:schedule_time] if args.key?(:schedule_time) @set_object_acls = args[:set_object_acls] if args.key?(:set_object_acls) @state = args[:state] if args.key?(:state) @update_object_custom_context = args[:update_object_custom_context] if args.key?(:update_object_custom_context) end |