Class: Google::Apis::StoragebatchoperationsV1::Job
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
The Storage Batch Operations Job description.
Instance Attribute Summary collapse
-
#bucket_list ⇒ Google::Apis::StoragebatchoperationsV1::BucketList
Describes list of buckets and their objects to be transformed.
-
#complete_time ⇒ String
Output only.
-
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
-
#create_time ⇒ String
Output only.
-
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
-
#description ⇒ String
Optional.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only.
-
#is_multi_bucket_job ⇒ Boolean
(also: #is_multi_bucket_job?)
Output only.
-
#logging_config ⇒ Google::Apis::StoragebatchoperationsV1::LoggingConfig
Specifies the Cloud Logging behavior.
-
#name ⇒ String
Identifier.
-
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
-
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
-
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
-
#schedule_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
519 520 521 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_list ⇒ Google::Apis::StoragebatchoperationsV1::BucketList
Describes list of buckets and their objects to be transformed.
Corresponds to the JSON property bucketList
428 429 430 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 428 def bucket_list @bucket_list end |
#complete_time ⇒ String
Output only. The time that the job was completed.
Corresponds to the JSON property completeTime
433 434 435 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 433 def complete_time @complete_time end |
#counters ⇒ Google::Apis::StoragebatchoperationsV1::Counters
Describes details about the progress of the job.
Corresponds to the JSON property counters
438 439 440 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 438 def counters @counters end |
#create_time ⇒ String
Output only. The time that the job was created.
Corresponds to the JSON property createTime
443 444 445 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 443 def create_time @create_time end |
#delete_object ⇒ Google::Apis::StoragebatchoperationsV1::DeleteObject
Describes options to delete an object.
Corresponds to the JSON property deleteObject
448 449 450 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 448 def delete_object @delete_object end |
#description ⇒ String
Optional. A description provided by the user for the job. Its max length is
1024 bytes when Unicode-encoded.
Corresponds to the JSON property description
454 455 456 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 454 def description @description end |
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. If true, the job will run in dry run mode, returning the total
object count and, if the object configuration is a prefix list, the bytes
found from source. No transformations will be performed.
Corresponds to the JSON property dryRun
461 462 463 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 461 def dry_run @dry_run end |
#error_summaries ⇒ Array<Google::Apis::StoragebatchoperationsV1::ErrorSummary>
Output only. Summarizes errors encountered with sample error log entries.
Corresponds to the JSON property errorSummaries
467 468 469 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 467 def error_summaries @error_summaries end |
#is_multi_bucket_job ⇒ Boolean Also known as: is_multi_bucket_job?
Output only. If true, this Job operates on multiple buckets. Multibucket jobs
are subject to different quota limits than single-bucket jobs.
Corresponds to the JSON property isMultiBucketJob
473 474 475 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 473 def is_multi_bucket_job @is_multi_bucket_job end |
#logging_config ⇒ Google::Apis::StoragebatchoperationsV1::LoggingConfig
Specifies the Cloud Logging behavior.
Corresponds to the JSON property loggingConfig
479 480 481 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 479 def logging_config @logging_config end |
#name ⇒ String
Identifier. The resource name of the Job. job_id is unique within the project,
that is either set by the customer or defined by the service. Format: projects/
project/locations/global/jobs/job_id . For example: "projects/123456/
locations/global/jobs/job01".
Corresponds to the JSON property name
487 488 489 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 487 def name @name end |
#put_metadata ⇒ Google::Apis::StoragebatchoperationsV1::PutMetadata
Describes options for object metadata update.
Corresponds to the JSON property putMetadata
492 493 494 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 492 def @put_metadata end |
#put_object_hold ⇒ Google::Apis::StoragebatchoperationsV1::PutObjectHold
Describes options to update object hold.
Corresponds to the JSON property putObjectHold
497 498 499 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 497 def put_object_hold @put_object_hold end |
#rewrite_object ⇒ Google::Apis::StoragebatchoperationsV1::RewriteObject
Describes options for object rewrite.
Corresponds to the JSON property rewriteObject
502 503 504 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 502 def rewrite_object @rewrite_object end |
#schedule_time ⇒ String
Output only. The time that the job was scheduled.
Corresponds to the JSON property scheduleTime
507 508 509 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 507 def schedule_time @schedule_time end |
#state ⇒ String
Output only. State of the job.
Corresponds to the JSON property state
512 513 514 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 512 def state @state end |
#update_object_custom_context ⇒ Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
Describes options to update object custom contexts.
Corresponds to the JSON property updateObjectCustomContext
517 518 519 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 517 def update_object_custom_context @update_object_custom_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 524 def update!(**args) @bucket_list = args[:bucket_list] if args.key?(:bucket_list) @complete_time = args[:complete_time] if args.key?(:complete_time) @counters = args[:counters] if args.key?(:counters) @create_time = args[:create_time] if args.key?(:create_time) @delete_object = args[:delete_object] if args.key?(:delete_object) @description = args[:description] if args.key?(:description) @dry_run = args[:dry_run] if args.key?(:dry_run) @error_summaries = args[:error_summaries] if args.key?(:error_summaries) @is_multi_bucket_job = args[:is_multi_bucket_job] if args.key?(:is_multi_bucket_job) @logging_config = args[:logging_config] if args.key?(:logging_config) @name = args[:name] if args.key?(:name) @put_metadata = args[:put_metadata] if args.key?(:put_metadata) @put_object_hold = args[:put_object_hold] if args.key?(:put_object_hold) @rewrite_object = args[:rewrite_object] if args.key?(:rewrite_object) @schedule_time = args[:schedule_time] if args.key?(:schedule_time) @state = args[:state] if args.key?(:state) @update_object_custom_context = args[:update_object_custom_context] if args.key?(:update_object_custom_context) end |