Class: Google::Apis::StoragebatchoperationsV1::Manifest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes list of objects to be transformed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Manifest

Returns a new instance of Manifest.



755
756
757
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#manifest_locationString

Required. manifest_location must contain the manifest source file that is a CSV file in a Google Cloud Storage bucket. Each row in the file must include the object details i.e. BucketId and Name. Generation may optionally be specified. When it is not specified the live object is acted upon. manifest_location should either be 1) An absolute path to the object in the format of gs://bucket_name/path/file_name.csv. 2) An absolute path with a single wildcard character in the file name, for example gs://bucket_name/path/ file_name*.csv. If manifest location is specified with a wildcard, objects in all manifest files matching the pattern will be acted upon. Corresponds to the JSON property manifestLocation

Returns:

  • (String)


753
754
755
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 753

def manifest_location
  @manifest_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



760
761
762
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 760

def update!(**args)
  @manifest_location = args[:manifest_location] if args.key?(:manifest_location)
end