Class: Google::Apis::StoragebatchoperationsV1::ObjectCustomContextPayload
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::ObjectCustomContextPayload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Describes the payload of a user-defined object custom context.
Instance Attribute Summary collapse
-
#value ⇒ String
The value of the object custom context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObjectCustomContextPayload
constructor
A new instance of ObjectCustomContextPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObjectCustomContextPayload
Returns a new instance of ObjectCustomContextPayload.
925 926 927 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#value ⇒ String
The value of the object custom context. If set, value can't be an empty
string because it is a required field in custom context. If unset, value is
ignored and no changes are made to the value field of the custom context
payload.
Corresponds to the JSON property value
923 924 925 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 923 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
930 931 932 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 930 def update!(**args) @value = args[:value] if args.key?(:value) end |