Class: Google::Apis::StoragebatchoperationsV1::ObjectCustomContextPayload
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::ObjectCustomContextPayload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Describes the payload of a user defined object custom context.
Instance Attribute Summary collapse
-
#value ⇒ String
The value of the object custom context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObjectCustomContextPayload
constructor
A new instance of ObjectCustomContextPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObjectCustomContextPayload
Returns a new instance of ObjectCustomContextPayload.
777 778 779 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#value ⇒ String
The value of the object custom context. If set, value must NOT be an empty
string since it is a required field in custom context. If unset, value will
be ignored and no changes will be made to the value field of the custom
context payload.
Corresponds to the JSON property value
775 776 777 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 775 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
782 783 784 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 782 def update!(**args) @value = args[:value] if args.key?(:value) end |