Class: Google::Apis::StoragebatchoperationsV1::PutMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes options for object metadata update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PutMetadata

Returns a new instance of PutMetadata.



1015
1016
1017
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_controlString

Optional. Updates objects Cache-Control fixed metadata. Unset values will be ignored. Set empty values to clear the metadata. Additionally, the value for Custom-Time cannot decrease. Refer to documentation in https://cloud.google. com/storage/docs/metadata#caching_data. Corresponds to the JSON property cacheControl

Returns:

  • (String)


961
962
963
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 961

def cache_control
  @cache_control
end

#content_dispositionString

Optional. Updates objects Content-Disposition fixed metadata. Unset values will be ignored. Set empty values to clear the metadata. Refer https://cloud. google.com/storage/docs/metadata#content-disposition for additional documentation. Corresponds to the JSON property contentDisposition

Returns:

  • (String)


969
970
971
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 969

def content_disposition
  @content_disposition
end

#content_encodingString

Optional. Updates objects Content-Encoding fixed metadata. Unset values will be ignored. Set empty values to clear the metadata. Refer to documentation in https://cloud.google.com/storage/docs/metadata#content-encoding. Corresponds to the JSON property contentEncoding

Returns:

  • (String)


976
977
978
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 976

def content_encoding
  @content_encoding
end

#content_languageString

Optional. Updates objects Content-Language fixed metadata. Refer to ISO 639-1 language codes for typical values of this metadata. Max length 100 characters. Unset values will be ignored. Set empty values to clear the metadata. Refer to documentation in https://cloud.google.com/storage/docs/metadata#content- language. Corresponds to the JSON property contentLanguage

Returns:

  • (String)


985
986
987
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 985

def content_language
  @content_language
end

#content_typeString

Optional. Updates objects Content-Type fixed metadata. Unset values will be ignored. Set empty values to clear the metadata. Refer to documentation in https://cloud.google.com/storage/docs/metadata#content-type Corresponds to the JSON property contentType

Returns:

  • (String)


992
993
994
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 992

def content_type
  @content_type
end

#custom_metadataHash<String,String>

Optional. Updates objects custom metadata. Adds or sets individual custom metadata key value pairs on objects. Keys that are set with empty custom metadata values will have its value cleared. Existing custom metadata not specified with this flag is not changed. Refer to documentation in https:// cloud.google.com/storage/docs/metadata#custom-metadata Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,String>)


1001
1002
1003
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1001

def 
  @custom_metadata
end

#custom_timeString

Optional. Updates objects Custom-Time fixed metadata. Unset values will be ignored. Set empty values to clear the metadata. Refer to documentation in https://cloud.google.com/storage/docs/metadata#custom-time. Corresponds to the JSON property customTime

Returns:

  • (String)


1008
1009
1010
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1008

def custom_time
  @custom_time
end

#object_retentionGoogle::Apis::StoragebatchoperationsV1::ObjectRetention

Describes options for object retention update. Corresponds to the JSON property objectRetention



1013
1014
1015
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1013

def object_retention
  @object_retention
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1020

def update!(**args)
  @cache_control = args[:cache_control] if args.key?(:cache_control)
  @content_disposition = args[:content_disposition] if args.key?(:content_disposition)
  @content_encoding = args[:content_encoding] if args.key?(:content_encoding)
  @content_language = args[:content_language] if args.key?(:content_language)
  @content_type = args[:content_type] if args.key?(:content_type)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @custom_time = args[:custom_time] if args.key?(:custom_time)
  @object_retention = args[:object_retention] if args.key?(:object_retention)
end