Class: Google::Apis::StoragebatchoperationsV1::RewriteObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes options for object rewrite.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RewriteObject

Returns a new instance of RewriteObject.



1075
1076
1077
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_keyString

Required. Resource name of the Cloud KMS key that will be used to encrypt the object. The Cloud KMS key must be located in same location as the object. Refer to https://cloud.google.com/storage/docs/encryption/using-customer- managed-keys#add-object-key for additional documentation. Format: projects/ project/locations/location/keyRings/keyring/cryptoKeys/key For example: "projects/123456/locations/us-central1/keyRings/my-keyring/cryptoKeys/my-key". The object will be rewritten and set with the specified KMS key. Corresponds to the JSON property kmsKey

Returns:

  • (String)


1073
1074
1075
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1073

def kms_key
  @kms_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1080
1081
1082
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1080

def update!(**args)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
end