Class: Google::Apis::StoragebatchoperationsV1::StorageBatchOperationsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::StoragebatchoperationsV1::StorageBatchOperationsService
- Defined in:
- lib/google/apis/storagebatchoperations_v1/service.rb
Overview
Storage Batch Operations API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://storagebatchoperations.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_job(name, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::CancelJobResponse
Cancels a batch job.
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_job(parent, job_object = nil, job_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Operation
Creates a batch job.
-
#delete_project_location_job(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Empty
Deletes a batch job.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Location
Gets information about a location.
-
#get_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Job
Gets a batch job.
-
#get_project_location_job_bucket_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::BucketOperation
Gets a BucketOperation.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ StorageBatchOperationsService
constructor
A new instance of StorageBatchOperationsService.
-
#list_project_location_job_bucket_operations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListBucketOperationsResponse
Lists BucketOperations in a given project and job.
-
#list_project_location_jobs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListJobsResponse
Lists Jobs in a given project.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListLocationsResponse
Lists information about the supported locations for this service.
Constructor Details
#initialize ⇒ StorageBatchOperationsService
Returns a new instance of StorageBatchOperationsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-storagebatchoperations_v1', client_version: Google::Apis::StoragebatchoperationsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_job(name, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::CancelJobResponse
Cancels a batch job.
162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 162 def cancel_job(name, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::StoragebatchoperationsV1::CancelJobRequest::Representation command.request_object = cancel_job_request_object command.response_representation = Google::Apis::StoragebatchoperationsV1::CancelJobResponse::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::CancelJobResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 438 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::StoragebatchoperationsV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::StoragebatchoperationsV1::Empty::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_job(parent, job_object = nil, job_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Operation
Creates a batch job.
205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 205 def create_project_location_job(parent, job_object = nil, job_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/jobs', ) command.request_representation = Google::Apis::StoragebatchoperationsV1::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::StoragebatchoperationsV1::Operation::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::Operation command.params['parent'] = parent unless parent.nil? command.query['jobId'] = job_id unless job_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_job(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Empty
Deletes a batch job.
251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 251 def delete_project_location_job(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::Empty::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::Empty command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
473 474 475 476 477 478 479 480 481 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 473 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::Empty::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::Location::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Job
Gets a batch job.
284 285 286 287 288 289 290 291 292 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 284 def get_project_location_job(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::Job::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::Job command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_job_bucket_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::BucketOperation
Gets a BucketOperation.
358 359 360 361 362 363 364 365 366 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 358 def get_project_location_job_bucket_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::BucketOperation::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::BucketOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
504 505 506 507 508 509 510 511 512 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 504 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::Operation::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_job_bucket_operations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListBucketOperationsResponse
Lists BucketOperations in a given project and job.
396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 396 def list_project_location_job_bucket_operations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/bucketOperations', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::ListBucketOperationsResponse::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::ListBucketOperationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_jobs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListJobsResponse
Lists Jobs in a given project.
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 322 def list_project_location_jobs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/jobs', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::ListJobsResponse::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::ListJobsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 549 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::ListOperationsResponse::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::StoragebatchoperationsV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/storagebatchoperations_v1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::StoragebatchoperationsV1::ListLocationsResponse::Representation command.response_class = Google::Apis::StoragebatchoperationsV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |