Class: Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
- Inherits:
-
Object
- Object
- Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb
Overview
Describes options to update object custom contexts.
Instance Attribute Summary collapse
-
#clear_all ⇒ Boolean
(also: #clear_all?)
If set, must be set to true and all existing object custom contexts are deleted.
-
#custom_context_updates ⇒ Google::Apis::StoragebatchoperationsV1::CustomContextUpdates
Describes a collection of updates to apply to custom contexts identified by key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateObjectCustomContext
constructor
A new instance of UpdateObjectCustomContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateObjectCustomContext
Returns a new instance of UpdateObjectCustomContext.
1455 1456 1457 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clear_all ⇒ Boolean Also known as: clear_all?
If set, must be set to true and all existing object custom contexts are
deleted.
Corresponds to the JSON property clearAll
1446 1447 1448 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1446 def clear_all @clear_all end |
#custom_context_updates ⇒ Google::Apis::StoragebatchoperationsV1::CustomContextUpdates
Describes a collection of updates to apply to custom contexts identified by
key.
Corresponds to the JSON property customContextUpdates
1453 1454 1455 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1453 def custom_context_updates @custom_context_updates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1460 1461 1462 1463 |
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1460 def update!(**args) @clear_all = args[:clear_all] if args.key?(:clear_all) @custom_context_updates = args[:custom_context_updates] if args.key?(:custom_context_updates) end |