Class: Google::Apis::StoragebatchoperationsV1::UpdateObjectCustomContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagebatchoperations_v1/classes.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb,
lib/google/apis/storagebatchoperations_v1/representations.rb

Overview

Describes options to update object custom contexts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateObjectCustomContext

Returns a new instance of UpdateObjectCustomContext.



1141
1142
1143
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clear_allBoolean Also known as: clear_all?

If set, must be set to true and all existing object custom contexts will be deleted. Corresponds to the JSON property clearAll

Returns:

  • (Boolean)


1132
1133
1134
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1132

def clear_all
  @clear_all
end

#custom_context_updatesGoogle::Apis::StoragebatchoperationsV1::CustomContextUpdates

Describes a collection of updates to apply to custom contexts identified by key. Corresponds to the JSON property customContextUpdates



1139
1140
1141
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1139

def custom_context_updates
  @custom_context_updates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1146
1147
1148
1149
# File 'lib/google/apis/storagebatchoperations_v1/classes.rb', line 1146

def update!(**args)
  @clear_all = args[:clear_all] if args.key?(:clear_all)
  @custom_context_updates = args[:custom_context_updates] if args.key?(:custom_context_updates)
end